#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for HDF5 libraries.
#---( Home Page: http://docs.rubygems.org/
#---( Source: http://rubyforge.org/frs/download.php/20989/rubygems-0.9.4.tgz
#---( Author: R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Thursday, June 14, 2007


#------------------( Set Package Name & Version )


soft='rubygems'
softversion='0.9.4'
packageversion='48.2'


#------------------( Check for source files )


if [ -f $soft-$softversion.tgz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Downloading it ..."
   wget -c ftp://ftp.ncsa.uiuc.edu/HDF/HDF5/current/src/$soft-$softversion.tgz
fi


#------------------( Check Prerequisites for Building )



if [ -f /usr/bin/ruby ]; then
   echo "ruby .. ok"
else
   echo "ruby is needed to build this package. Please install ruby first."
   exit 1 ;
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tgz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"
export GEM_HOME=$dest/usr/lib/ruby/gems/1.8


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .

find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


#------------------( Install Files for Packaging )


cd $src
ruby setup.rb config --prefix=/usr
ruby setup.rb setup
ruby setup.rb install --prefix=$dest


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
cp -a ChangeLog GPLtxt InstalledFiles License.txt README Reseases $dest/usr/doc/$soft-$softversion


#------------------( Copy the Buildscript )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
        |-----handy-ruler------------------------------------------------------|
rubygems: RubyGems (A package management framework for the Ruby language)
rubygems: 
rubygems: A package management framework for the Ruby programming language.
rubygems: 
rubygems: Required: ruby >= 1.8.6.
rubygems: 
rubygems: 
rubygems: 
rubygems: 
rubygems: 
rubygems: 
EOF


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5
zen_pkgcheck_new.pl $package.tgz